@@ -49,13 +49,15 @@ from ..models.settings import settings
 from ..utils.copy_manager import CopyManager
 from ..utils.date import date_to_string
 from ..utils.dependency_graph import DependencyGraph
-from ..utils.logging import FormattedSingleMessageGtkInfoBarHandler, DefaultFilter
+from ..utils.logging import FormattedSingleMessageGtkInfoBarHandler, DefaultFilter, _log_nested
 from ..utils.query import (is_valid_query, dump_single_line_query_text)
+from ..utils.subprocess import launch_default_app_for_uri
 from ..widgets.base_uri_list_box import LOOKUP_BASE_URI
 from ..widgets.base_uri_row import DtoolBaseURIRow
 from ..widgets.search_popover import DtoolSearchPopover
 from ..widgets.search_results_row import DtoolSearchResultsRow
 from .dataset_name_dialog import DatasetNameDialog
+from .about_dialog import AboutDialog
 from .settings_dialog import SettingsDialog
 from .log_window import LogWindow
 
@@ -179,8 +181,10 @@ class MainWindow(Gtk.ApplicationWindow):
 
         # connect a search popover with search entry
         self.search_popover = DtoolSearchPopover(search_entry=self.search_entry)
+
         self.log_window = LogWindow(application=self.application)
         self.settings_dialog = SettingsDialog(application=self.application)
+        self.about_dialog = AboutDialog(application=self.application)
 
         # window-scoped actions
 
@@ -508,6 +512,10 @@ class MainWindow(Gtk.ApplicationWindow):
     def on_logging_clicked(self, widget):
         self.log_window.show()
 
+    @Gtk.Template.Callback()
+    def on_about_clicked(self, widget):
+        self.about_dialog.show()
+
     @Gtk.Template.Callback()
     def on_base_uri_selected(self, list_box, row):
         if row is None:
@@ -564,6 +572,16 @@ class MainWindow(Gtk.ApplicationWindow):
         search_text = self.search_entry.get_text()
         self._search_by_search_text(search_text)
 
+    @Gtk.Template.Callback()
+    def on_search_drop_down_clicked(self, widget):
+        if self.search_popover.get_visible():
+            _logger.debug(
+                f"Search entry drop down icon pressed, hide popover.")
+            self.search_popover.popdown()
+        else:
+            _logger.debug(f"Search entry drop down icon pressed, show popover.")
+            self.search_popover.popup_at(widget)
+
     @Gtk.Template.Callback()
     def on_dataset_selected(self, list_box, row):
         if row is not None:
@@ -628,7 +646,8 @@ class MainWindow(Gtk.ApplicationWindow):
 
     @Gtk.Template.Callback()
     def on_show_clicked(self, widget):
-        Gio.AppInfo.launch_default_for_uri(str(self.dataset_list_box.get_selected_row().dataset))
+        uri = str(self.dataset_list_box.get_selected_row().dataset)
+        launch_default_app_for_uri(uri)
 
     @Gtk.Template.Callback()
     def on_add_items_clicked(self, widget):
